@@ -24,7 +24,7 @@
 
 #define QMMP_VERSION_MAJOR 1
 #define QMMP_VERSION_MINOR 1
-#define QMMP_VERSION_PATCH 0
+#define QMMP_VERSION_PATCH 1
 #define QMMP_VERSION_STABLE 1
 
 #define QMMP_VERSION_INT (QMMP_VERSION_MAJOR<<16 | QMMP_VERSION_MINOR<<8 | QMMP_VERSION_PATCH)
@@ -158,10 +158,19 @@ public:
      * @param code Language code; code "auto" means autodetection.
      */
     static void setUiLanguageID(const QString &code);
+#ifdef Q_OS_WIN
+    /*!
+     * Returns \b true if portable mode is enabled. Otherwise returns \b false.
+     */
+    static bool isPortable();
+#endif
 
 private:
     static QString m_configDir;
     static QString m_langID;
+#ifdef Q_OS_WIN
+    static QString m_appDir;
+#endif
 
 };
 
